@@ -1,13 +1,6 @@
 package Clustericious::RouteBuilder;
-
 use strict;
 use warnings;
-use 5.010;
-use Log::Log4perl qw( :easy );
-
-# ABSTRACT: Route builder for Clustericious applications
-our $VERSION = '0.9940_04'; # VERSION
-
 
 our %Routes;
 
@@ -103,12 +96,12 @@ sub import {
     *{"${caller}::authorize"}    = sub { $route_sub->('authorize',@_) };
 }
 
-sub _add_routes {
+sub add_routes {
     my $class = shift;
     my $app = shift;
-    my $auth_plugin = shift;
 
-    my $stashed = $Routes{ ref $app } // do { WARN "no routes stashed for $app"; [] };
+    my $stashed = $Routes{ ref $app }
+      or Carp::confess("no routes stashed for $app");
     my @stashed            = @$stashed;
     my $routes             = $app->routes;
     my $head_route         = $app->routes;
@@ -121,9 +114,15 @@ sub _add_routes {
          # authenticate, always connects to app->routes
          if (!ref $methods && $methods eq 'authenticate') {
              my $realm = $pattern || ref $app;
-             my $cb = defined $auth_plugin ? sub { $auth_plugin->authenticate(shift, $realm) } : sub { 1 };
              $head_route = $head_authenticated = $routes =
-             $app->routes->bridge->to( { cb => $cb } )->name("authenticated");
+             $app->routes->bridge->to( {
+                    cb => sub {
+                        my $c = shift;
+                        return 1 unless $c->config->simple_auth(default => '');
+                        $c->app->plugins->load_plugin('simple_auth')
+                            ->authenticate( $c, $realm );
+                      }
+                })->name("authenticated");
              next;
          }
 
@@ -132,24 +131,19 @@ sub _add_routes {
             die "put authenticate before authorize" unless $head_authenticated;
             my $action = $pattern;
             my $resource = $name;
-            if($auth_plugin)
-            {
-                $head_route = $routes = $head_authenticated->bridge->to( {
-                        cb => sub {
-                            my $c = shift;
-                            # Dynamically compute resource/action
-                            my ($d_resource,$d_action) = ($resource, $action);
-                            $d_resource =~ s/<path>/$c->req->url->path/e if $d_resource;
-                            $d_resource ||= $c->req->url->path;
-                            $d_action =~ s/<method>/$c->req->method/e if $d_action;
-                            $d_action ||= $c->req->method;
-                            $auth_plugin->authorize( $c, $d_action, $d_resource );
-                          } });
-            }
-            else
-            {
-                $head_route = $routes = $head_authenticated->bridge->to({ cb => sub { 1 } });
-            }
+            $head_route = $routes = $head_authenticated->bridge->to( {
+                    cb => sub {
+                        my $c = shift;
+                        return 1 unless $c->config->simple_auth(default => '');
+                        # Dynamically compute resource/action
+                        my ($d_resource,$d_action) = ($resource, $action);
+                        $d_resource =~ s/<path>/$c->req->url->path/e if $d_resource;
+                        $d_resource ||= $c->req->url->path;
+                        $d_action =~ s/<method>/$c->req->method/e if $d_action;
+                        $d_action ||= $c->req->method;
+                        $c->app->plugins->load_plugin('simple_auth')
+                            ->authorize( $c, $d_action, $d_resource );
+                      } });
             next;
          }
 
@@ -177,100 +171,3 @@ sub _add_routes {
 
 1;
 
-
-__END__
-=pod
-
-=head1 NAME
-
-Clustericious::RouteBuilder - Route builder for Clustericious applications
-
-=head1 VERSION
-
-version 0.9940_04
-
-=head1 SYNOPSIS
-
- package MyApp;
- 
- use Mojo::Base qw( Clustericious::App );
- 
- package MyApp::Routes;
-
- use Clustericious::RouteBuilder;
- 
- get '/' => sub { shift->render(text => 'welcome to myapp') };
-
-=head1 DESCRIPTION
-
-This module provides a simplified interface for creating routes for your 
-L<Clustericious> application.  To use it, create a Routes.pm that lives 
-directly under your application's namespace (for example above MyApp's 
-route module is MyApp::Routes).  The interface is reminiscent of 
-L<Mojolicious::Lite>, because it was forked from there some time ago.
-
-=head1 SUPER CLASS
-
-none
-
-=head1 METHODS
-
-=head2 any
-
-Define an HTTP route that matches any HTTP command verb.
-
-=head2 get
-
-Define an HTTP GET route
-
-=head2 head
-
-Define an HTTP HEAD route
-
-=head2 post
-
-Define an HTTP POST route
-
-=head2 put
-
-Define an HTTP PUT route
-
-=head2 del
-
-Define an HTTP DELETE route.
-
-=head2 websocket
-
-Define a Websocket route.
-
-=head2 authenticate
-
-Require authentication for all subsequent routes.
-
-=head2 authorize [ $action ]
-
-Require specific authorization for all subsequent routes.
-
-=head1 SEE ALSO
-
-L<Clustericious>, L<Mojolicious::Lite>
-
-=head1 AUTHOR
-
-original author: Brian Duggan
-
-current maintainer: Graham Ollis <plicease@cpan.org>
-
-contributors:
-
-Curt Tilmes
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
-
